@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2014 Rony Shapiro <ronys@users.sourceforge.net>.
+* Copyright (c) 2003-2015 Rony Shapiro <ronys@users.sourceforge.net>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -48,19 +48,13 @@
 const TCHAR *EXPORTHEADER  = _T("Group/Title\tUsername\tPassword\tURL\tAutoType\tCreated Time\tPassword Modified Time\tLast Access Time\tPassword Expiry Date\tPassword Expiry Interval\tRecord Modified Time\tPassword Policy\tPassword Policy Name\tHistory\tRun Command\tDCA\tShift+DCA\te-mail\tProtected\tSymbols\tKeyboard Shortcut\tNotes");
 const TCHAR *KPEXPORTHEADER  = _T("Password Groups\tGroup Tree\tAccount\tLogin Name\tPassword\tWeb Site\tComments\tUUID\tIcon\tCreation Time\tLast Access\tLast Modification\tExpires\tAttachment Description\tAttachment");
 const TCHAR *KPIMPORTEDPREFIX = _T("ImportedKeePass");
-const TCHAR *GROUPTITLEUSERINCHEVRONS = _T("\xab%s\xbb \xab%s\xbb \xab%s\xbb");
+const TCHAR *GROUPTITLEUSERINCHEVRONS = _T("\xab%ls\xbb \xab%ls\xbb \xab%ls\xbb");
 
 using namespace std;
 using pws_os::CUUID;
 
-// hide w_char/char differences where possible:
-#ifdef UNICODE
 typedef std::wifstream ifstreamT;
 typedef std::wofstream ofstreamT;
-#else
-typedef std::ifstream ifstreamT;
-typedef std::ofstream ofstreamT;
-#endif
 typedef std::vector<stringT>::iterator viter;
 
 struct ExportTester {
@@ -473,7 +467,7 @@ int PWScore::WriteXMLFile(const StringX &filename,
   coStringXStream ofs;
   oStringXStream oss_xml;
 
-  StringX pwh, tmp;
+  StringX tmp;
   stringT cs_temp;
   time_t time_now;
 
@@ -656,12 +650,12 @@ int PWScore::WriteXMLFile(const StringX &filename,
 
       hdr = BuildHeader(bsFields, false);
       size_t found = hdr.find(_T("\t"));
-	    while (found != StringX::npos) {
-		    if (found != StringX::npos) {
-			    hdr.replace(found, 1, _T(", "));
-		    }
-		    found = hdr.find(_T("\t"));
-	    }
+      while (found != StringX::npos) {
+        if (found != StringX::npos) {
+          hdr.replace(found, 1, _T(", "));
+        }
+        found = hdr.find(_T("\t"));
+      }
       hdr = _T("     ") + hdr;
       conv.ToUTF8(hdr, utf8, utf8Len);
       ofs.write(reinterpret_cast<const char *>(utf8), utf8Len);
@@ -819,7 +813,6 @@ int PWScore::ImportPlaintextFile(const StringX &ImportedPrefix,
   cStringXStream iss;
   unsigned char buffer[IMPORT_BUFFER_SIZE + 1];
   bool bError(false);
-  size_t total(0);
   while(!feof(fs)) {
     size_t count = fread(buffer, 1, IMPORT_BUFFER_SIZE, fs);
     if (ferror(fs)) {
@@ -828,7 +821,6 @@ int PWScore::ImportPlaintextFile(const StringX &ImportedPrefix,
     }
     buffer[count] = '\0';
     iss << buffer;
-    total += count;
   }
 
   // Close the file
@@ -984,7 +976,7 @@ int PWScore::ImportPlaintextFile(const StringX &ImportedPrefix,
         const string &sHdr = vs_Header.at(i);
         StringX sh2;
         conv.FromUTF8(reinterpret_cast<const unsigned char *>(sHdr.c_str()), sHdr.length(), sh2);
-        Format(cs_error, _T(" %s,"), sh2.c_str());
+        Format(cs_error, L" %ls,", sh2.c_str());
         rpt.WriteLine(cs_error, false);
       }
     }
@@ -1138,7 +1130,6 @@ int PWScore::ImportPlaintextFile(const StringX &ImportedPrefix,
     if (bImportPSWDsOnly) {
       StringX sxgroup(_T("")), sxtitle, sxuser;
       const stringT &grouptitle = tokens[i_Offset[GROUPTITLE]];
-      stringT entrytitle;
       size_t lastdot = grouptitle.find_last_of(TCHAR('.'));
       if (lastdot != stringT::npos) {
         sxgroup = grouptitle.substr(0, lastdot).c_str();
@@ -1495,7 +1486,6 @@ int PWScore::ImportKeePassV1TXTFile(const StringX &filename,
   cStringXStream iss;
   unsigned char buffer[IMPORT_BUFFER_SIZE + 1];
   bool bError(false);
-  size_t total(0);
   while(!feof(fs)) {
     size_t count = fread(buffer, 1, IMPORT_BUFFER_SIZE, fs);
     if (ferror(fs)) {
@@ -1504,7 +1494,6 @@ int PWScore::ImportKeePassV1TXTFile(const StringX &filename,
     }
     buffer[count] = '\0';
     iss << buffer;
-    total += count;
   }
 
   // Close the file
@@ -1681,12 +1670,8 @@ int PWScore::ImportKeePassV1TXTFile(const StringX &filename,
         if (str_ctime.length() != 19)
           continue;
         str_ctime.replace(10, 1, "T");
-#ifdef UNICODE
         std::wstring time_temp(str_ctime.length(), L' ');
         std::copy(str_ctime.begin(), str_ctime.end(), time_temp.begin());
-#else
-        std::string time_temp = str_ctime;
-#endif
         VerifyXMLDateTimeString(time_temp, ctime);
       }
 
@@ -1695,12 +1680,8 @@ int PWScore::ImportKeePassV1TXTFile(const StringX &filename,
         if (str_atime.length() != 19)
           continue;
         str_atime.replace(10, 1, "T");
-#ifdef UNICODE
         std::wstring time_temp(str_atime.length(), L' ');
         std::copy(str_atime.begin(), str_atime.end(), time_temp.begin());
-#else
-        std::string time_temp = str_atime;
-#endif
         VerifyXMLDateTimeString(time_temp, atime);
       }
 
@@ -1709,12 +1690,8 @@ int PWScore::ImportKeePassV1TXTFile(const StringX &filename,
         if (str_mtime.length() != 19)
           continue;
         str_mtime.replace(10, 1, "T");
-#ifdef UNICODE
         std::wstring time_temp(str_mtime.length(), L' ');
         std::copy(str_mtime.begin(), str_mtime.end(), time_temp.begin());
-#else
-        std::string time_temp = str_mtime;
-#endif
         VerifyXMLDateTimeString(time_temp, mtime);
       }
 
@@ -1723,12 +1700,8 @@ int PWScore::ImportKeePassV1TXTFile(const StringX &filename,
         if (str_xtime.length() != 19)
           continue;
         str_xtime.replace(10, 1, "T");
-#ifdef UNICODE
         std::wstring time_temp(str_xtime.length(), L' ');
         std::copy(str_xtime.begin(), str_xtime.end(), time_temp.begin());
-#else
-        std::string time_temp = str_xtime;
-#endif
         VerifyXMLDateTimeString(time_temp, xtime);
       }
 
@@ -1842,7 +1815,6 @@ int PWScore::ImportKeePassV1TXTFile(const StringX &filename,
 
 void ProcessKeePassCSVLine(const string &linebuf, std::vector<StringX> &tokens)
 {
-  char ch;
   bool bInField = false;
   CUTF8Conv conv;
 
@@ -1850,7 +1822,7 @@ void ProcessKeePassCSVLine(const string &linebuf, std::vector<StringX> &tokens)
   StringX sxdata;
 
   for(size_t i = 0; i < linebuf.length(); i++ ) {
-    ch = linebuf[i];
+    char ch = linebuf[i];
 
     if(ch == 0)
       continue;
@@ -2035,7 +2007,7 @@ int PWScore::ImportKeePassV1CSVFile(const StringX &filename,
     rpt.WriteLine(strError);
     for (int i = 0; i < NUMFIELDS; i++) {
       if (i_Offset[i] >= 0) {
-        Format(strError, _T(" %s,"), vs_Header[i].c_str());
+        Format(strError, L" %ls,", vs_Header[i].c_str());
         rpt.WriteLine(strError, false);
       }
     }
@@ -2197,12 +2169,8 @@ int PWScore::ImportKeePassV1CSVFile(const StringX &filename,
       if (sx_ctime.length() != 19)
         continue;
       sx_ctime.replace(10, 1, _T("T"));
-#ifdef UNICODE
       std::wstring time_temp(sx_ctime.length(), L' ');
       std::copy(sx_ctime.begin(), sx_ctime.end(), time_temp.begin());
-#else
-      std::string time_temp = sx_ctime;
-#endif
       VerifyXMLDateTimeString(time_temp, ctime);
     }
 
@@ -2211,12 +2179,8 @@ int PWScore::ImportKeePassV1CSVFile(const StringX &filename,
       if (sx_atime.length() != 19)
         continue;
       sx_atime.replace(10, 1, _T("T"));
-#ifdef UNICODE
       std::wstring time_temp(sx_atime.length(), L' ');
       std::copy(sx_atime.begin(), sx_atime.end(), time_temp.begin());
-#else
-      std::string time_temp = sx_atime;
-#endif
       VerifyXMLDateTimeString(time_temp, atime);
     }
 
@@ -2225,12 +2189,8 @@ int PWScore::ImportKeePassV1CSVFile(const StringX &filename,
       if (sx_mtime.length() != 19)
         continue;
       sx_mtime.replace(10, 1, _T("T"));
-#ifdef UNICODE
       std::wstring time_temp(sx_mtime.length(), L' ');
       std::copy(sx_mtime.begin(), sx_mtime.end(), time_temp.begin());
-#else
-      std::string time_temp = sx_mtime;
-#endif
       VerifyXMLDateTimeString(time_temp, mtime);
     }
 
@@ -2239,12 +2199,8 @@ int PWScore::ImportKeePassV1CSVFile(const StringX &filename,
       if (sx_xtime.length() != 19)
         continue;
       sx_xtime.replace(10, 1, _T("T"));
-#ifdef UNICODE
       std::wstring time_temp(sx_xtime.length(), L' ');
       std::copy(sx_xtime.begin(), sx_xtime.end(), time_temp.begin());
-#else
-      std::string time_temp = sx_xtime;
-#endif
       VerifyXMLDateTimeString(time_temp, xtime);
     }
 
