@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2011 Rony Shapiro <ronys@users.sourceforge.net>.
+* Copyright (c) 2003-2015 Rony Shapiro <ronys@users.sourceforge.net>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -9,9 +9,10 @@
 #include "../sleep.h"
 #include "./xsendstring.h"
 #include "../../core/Util.h"
+#include "../../core/PWSprefs.h"
 
-CKeySend::CKeySend(bool)
-  : m_delayMS(10) //default delay after each keystroke is 10 ms
+CKeySend::CKeySend(bool, unsigned defaultDelay)
+  : m_delayMS(defaultDelay)
 {
 }
 
@@ -21,7 +22,15 @@ CKeySend::~CKeySend()
 
 void CKeySend::SendString(const StringX &data)
 {
-  pws_os::SendString(data, pws_os::ATMETHOD_AUTO, m_delayMS);
+  /**
+   * Default method is via XSendKeys. Since this may be blocked,
+   * we also support XTEST, even though the latter is less capable (?)
+   */
+
+  bool useAlt = PWSprefs::GetInstance()->GetPref(PWSprefs::UseAltAutoType);
+  pws_os::AutotypeMethod am = useAlt ? pws_os::ATMETHOD_XTEST : pws_os::ATMETHOD_XSENDKEYS;
+
+  pws_os::SendString(data, am, m_delayMS);
 }
 
 void CKeySend::SetDelay(unsigned d)
