@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2011 Rony Shapiro <ronys@users.sourceforge.net>.
+* Copyright (c) 2003-2015 Rony Shapiro <ronys@users.sourceforge.net>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -12,13 +12,20 @@
 
 #include "SecString.h"
 #include "core/PwsPlatform.h"
-#include "PWDialog.h"
+#include <afxwin.h>
 
-class CCryptKeyEntry : public CPWDialog
+/**
+ * This dialog box is used for the "undocumented" file encryption/decryption mode.
+ * This means that it's invoked instead of DboxMain, and specifically before our
+ * framework is fully initialized. This is why this MUST be a CDialog, and NOT
+ * CPWDialog derived class.
+ */
+
+class CCryptKeyEntry : public CDialog
 {
   // Construction
 public:
-  CCryptKeyEntry(CWnd* pParent = NULL);   // standard constructor
+  CCryptKeyEntry(bool isEncrypt, CWnd* pParent = NULL);
 
   // Dialog Data
   //{{AFX_DATA(CCryptKeyEntry)
@@ -37,17 +44,17 @@ protected:
 
   // Implementation
 protected:
+  virtual BOOL OnInitDialog();
   // Generated message map functions
   //{{AFX_MSG(CCryptKeyEntry)
   virtual void OnCancel();
   virtual void OnOK();
   afx_msg void OnHelp();
-#if defined(POCKET_PC)
-  afx_msg void OnPasskeySetfocus();
-  afx_msg void OnPasskeyKillfocus();
-#endif
   //}}AFX_MSG
   DECLARE_MESSAGE_MAP()
+private:
+  bool m_encrypt; // from c'tor. False == decrypt, don't confirm password
+  
 };
 
 //-----------------------------------------------------------------------------
