@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2013 Rony Shapiro <ronys@users.sourceforge.net>.
+* Copyright (c) 2003-2015 Rony Shapiro <ronys@users.sourceforge.net>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -122,7 +122,7 @@ void DboxMain::OnAdd()
         (prefs->GetPref(PWSprefs::QuerySetDef)) &&
         (!sxUsername.IsEmpty())) {
       CQuerySetDef defDlg(this);
-      defDlg.m_message.Format(IDS_SETUSERNAME, (const CString&)sxUsername);
+      defDlg.m_defaultusername.Format(IDS_SETUSERNAME, (const CString&)sxUsername);
 
       INT_PTR rc2 = defDlg.DoModal();
 
@@ -232,7 +232,7 @@ void DboxMain::OnCreateShortcut()
         (prefs->GetPref(PWSprefs::QuerySetDef)) &&
         (!dlg_createshortcut.m_username.IsEmpty())) {
       CQuerySetDef defDlg(this);
-      defDlg.m_message.Format(IDS_SETUSERNAME, (const CString&)dlg_createshortcut.m_username);
+      defDlg.m_defaultusername.Format(IDS_SETUSERNAME, (const CString&)dlg_createshortcut.m_username);
       INT_PTR rc2 = defDlg.DoModal();
       if (rc2 == IDOK) {
         // Initialise a copy of the DB preferences
@@ -988,7 +988,7 @@ void DboxMain::OnEdit()
         EditShortcut(pci);
       else
         EditItem(pci);
-    } catch (CString err) {
+    } catch (CString &err) {
       CGeneralMsgBox gmb;
       gmb.MessageBox(err, NULL, MB_OK | MB_ICONERROR);
     }
@@ -997,11 +997,10 @@ void DboxMain::OnEdit()
     // perhaps not the most elegant solution to improving non-mouse use,
     // but it works. If anyone knows how Enter/Return gets mapped to OnEdit,
     // let me know...
-    CItemData *pci_node(NULL);
     if (m_ctlItemTree.IsWindowVisible()) { // tree view
       HTREEITEM ti = m_ctlItemTree.GetSelectedItem();
       if (ti != NULL) { // if anything selected
-        pci_node = (CItemData *)m_ctlItemTree.GetItemData(ti);
+        CItemData *pci_node = (CItemData *)m_ctlItemTree.GetItemData(ti);
         if (pci_node == NULL) { // node selected
           m_ctlItemTree.Expand(ti, TVE_TOGGLE);
         }
@@ -1865,7 +1864,6 @@ void DboxMain::AddDDEntries(CDDObList &in_oblist, const StringX &DropGroup)
   StringX sxgroup, sxtitle, sxuser;
   POSITION pos;
   wchar_t *dot;
-  bool bAddToViews;
 
   const StringX sxDD_DateTime = PWSUtil::GetTimeStamp(true).c_str();
 
@@ -1877,15 +1875,11 @@ void DboxMain::AddDDEntries(CDDObList &in_oblist, const StringX &DropGroup)
 
   for (pos = in_oblist.GetHeadPosition(); pos != NULL; in_oblist.GetNext(pos)) {
     CDDObject *pDDObject = (CDDObject *)in_oblist.GetAt(pos);
-#ifdef DEMO
-    if (m_core.GetNumEntries() >= MAXDEMO)
-      break;
-#endif /* DEMO */
 
     bool bChangedPolicy(false);
     ci_temp.Clear();
     // Only set to false if adding a shortcut where the base isn't there (yet)
-    bAddToViews = true;
+    bool bAddToViews = true;
     pDDObject->ToItem(ci_temp);
 
     StringX sxPolicyName = ci_temp.GetPolicyName();
@@ -1946,8 +1940,8 @@ void DboxMain::AddDDEntries(CDDObList &in_oblist, const StringX &DropGroup)
 
     if (bChangedPolicy) {
       StringX sxChanged = L"\r\n\xab" + sxgroup + L"\xbb " +
-	                        L"\xab" + sxnewtitle + L"\xbb " +
-	                        L"\xab" + sxuser + L"\xbb";
+                          L"\xab" + sxnewtitle + L"\xbb " +
+                          L"\xab" + sxuser + L"\xbb";
       sxEntriesWithNewNamedPolicies += sxChanged;
     }
 
