@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2013 Rony Shapiro <ronys@users.sourceforge.net>.
+* Copyright (c) 2003-2015 Rony Shapiro <ronys@users.sourceforge.net>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -8,7 +8,7 @@
 
 #pragma once
 
-class DboxMain;
+class DboxMain; // for GetMainDlg()
 
 class CPWPropertySheet : public CPropertySheet
 {
@@ -26,14 +26,16 @@ public:
 protected:
   DECLARE_DYNAMIC(CPWPropertySheet)
 
+  DboxMain *GetMainDlg() const;
+
   afx_msg void OnWindowPosChanging(WINDOWPOS *lpwndpos);
   afx_msg void OnShowWindow(BOOL bShow, UINT nStatus);
+  afx_msg LRESULT OnMenuChar(UINT nChar, UINT nFlags, CMenu *pMenu);
 
   DECLARE_MESSAGE_MAP()
   
 private:
   // Used to determine if Tall will fit in OnInitDialog
-  DboxMain *m_pDbx;
   bool m_bLongPPs;
   bool m_bKeepHidden;
 };
