@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2014 Rony Shapiro <ronys@users.sourceforge.net>.
+* Copyright (c) 2003-2015 Rony Shapiro <ronys@users.sourceforge.net>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -159,10 +159,6 @@ BOOL CPasskeyEntry::OnInitDialog(void)
       GetDlgItem(IDC_READONLY)->EnableWindow(m_bForceReadOnly ? FALSE : TRUE);
       GetDlgItem(IDC_READONLY)->ShowWindow(SW_SHOW);
       GetDlgItem(IDC_VERSION)->SetWindowText(m_appversion);
-#ifdef DEMO
-      GetDlgItem(IDC_SPCL_TXT)->
-         SetWindowText(CString(MAKEINTRESOURCE(IDS_DEMO)));
-#endif
       break;
     case GCP_NORMAL:
       // otherwise during open - user can - again unless file is R-O
