@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-2012 Rony Shapiro <ronys@users.sourceforge.net>.
+ * Copyright (c) 2003-2015 Rony Shapiro <ronys@users.sourceforge.net>.
  * All rights reserved. Use of the code is allowed under the
  * Artistic License 2.0 terms, as specified in the LICENSE file
  * distributed with this code, or available from
@@ -40,6 +40,7 @@
 #include "../../core/PWSAuxParse.h"
 #include "../../core/Util.h"
 #include "../../os/KeySend.h"
+#include "../../os/run.h"
 #include "../../os/sleep.h"
 #include "../../os/utf8conv.h"
 
@@ -102,7 +103,7 @@ void PasswordSafeFrame::OnAddClick( wxCommandEvent& /* evt */ )
 {
   wxString selectedGroup = wxEmptyString;
   wxTreeItemId selection;
-  if (IsTreeView() && (selection = m_tree->GetSelection()).IsOk() && m_tree->ItemHasChildren(selection)) {
+  if (IsTreeView() && (selection = m_tree->GetSelection()).IsOk() && m_tree->ItemIsGroup(selection)) {
     selectedGroup = m_tree->GetItemGroup(selection);
   }
 
@@ -120,7 +121,7 @@ void PasswordSafeFrame::OnAddClick( wxCommandEvent& /* evt */ )
 
 void PasswordSafeFrame::OnDeleteClick( wxCommandEvent& /* evt */ )
 {
-  bool dontaskquestion = !PWSprefs::GetInstance()->
+  bool dontaskquestion = PWSprefs::GetInstance()->
     GetPref(PWSprefs::DeleteQuestion);
 
   bool dodelete = true;
@@ -136,10 +137,12 @@ void PasswordSafeFrame::OnDeleteClick( wxCommandEvent& /* evt */ )
   //Confirm whether to delete the item
   if (!dontaskquestion) {
     DeleteConfirmation deleteDlg(this, num_children);
+    deleteDlg.SetConfirmdelete(PWSprefs::GetInstance()->GetPref(PWSprefs::DeleteQuestion));
     int rc = deleteDlg.ShowModal();
     if (rc != wxID_YES) {
       dodelete = false;
     }
+    PWSprefs::GetInstance()->SetPref(PWSprefs::DeleteQuestion, deleteDlg.GetConfirmdelete());
   }
 
   if (dodelete) {
@@ -147,7 +150,7 @@ void PasswordSafeFrame::OnDeleteClick( wxCommandEvent& /* evt */ )
     CItemData *item = GetSelectedEntry();
     if (item != NULL) {
       doit = Delete(item);
-    } else if (num_children > 0) {
+    } else if (m_tree->GetSelection() != m_tree->GetRootItem()) {
       doit = Delete(m_tree->GetSelection());
     }
     if (doit != NULL)
@@ -172,32 +175,41 @@ Command *PasswordSafeFrame::Delete(wxTreeItemId tid)
   // Called for deleting a group
   // Recursively build the appropriate multi-command
 
+  if (!tid) return NULL;
   MultiCommands *retval = MultiCommands::Create(&m_core);
-  ASSERT(tid.IsOk());
   if (m_tree->GetChildrenCount(tid) > 0) {
     wxTreeItemIdValue cookie;
     wxTreeItemId ti = m_tree->GetFirstChild(tid, cookie);
-    
-    while (ti) {
+
+    while (ti.IsOk()) {
       Command *delCmd = Delete(ti);
       if (delCmd != NULL)
         retval->Add(delCmd);
-      // go through all siblings too
-      wxTreeItemId sibling = m_tree->GetNextSibling(ti);
-      while (sibling.IsOk()) {
-        Command *delSibCmd = Delete(sibling);
-        if (delSibCmd != NULL)
-          retval->Add(delSibCmd);
-        sibling = m_tree->GetNextSibling(sibling);
-      } // while siblings
-      ti = m_tree->GetNextChild(ti, cookie);
+      ti = m_tree->GetNextChild(tid, cookie);
     } // while children
+    // Explicitly delete any empty groups coinciding with this wxTreeItem's group hierarchy
+    // Otherwise the user will see a these empty groups still hanging around inspite
+    // of just deleting the parent/ancestor
+    StringX sxGroup = tostringx(m_tree->GetItemGroup(tid));
+    if (m_core.IsEmptyGroup(sxGroup)) {
+      Command *delGrp = DBEmptyGroupsCommand::Create(&m_core, sxGroup, DBEmptyGroupsCommand::EG_DELETE);
+      if (delGrp)
+        retval->Add(delGrp);
+    }
   } else { // leaf
     CItemData *leaf = m_tree->GetItem(tid);
-    ASSERT(leaf != NULL);
-    Command *delLeafCmd = Delete(leaf); // gets user conf. if needed
-    if (delLeafCmd != NULL)
-      retval->Add(delLeafCmd);
+    if (leaf != NULL) {
+      Command *delLeafCmd = Delete(leaf); // gets user conf. if needed
+      if (delLeafCmd != NULL)
+        retval->Add(delLeafCmd);
+    }
+    else {
+      wxASSERT_MSG(m_tree->ItemIsGroup(tid), wxT("Childless item without CItemData must be an empty group"));
+      StringX sxGroup = tostringx(m_tree->GetItemGroup(tid));
+      Command *delGrp = DBEmptyGroupsCommand::Create(&m_core, sxGroup, DBEmptyGroupsCommand::EG_DELETE);
+      if (delGrp)
+        retval->Add(delGrp);
+    }
   }
 
   // If MultiCommands is empty, delete and return NULL
@@ -264,6 +276,24 @@ void PasswordSafeFrame::DoCopyPassword(CItemData &item)
   UpdateAccessTime(item);
 }
 
+/*!
+ * wxEVT_COMMAND_MENU_SELECTED event handler for ID_COPYRUNCOMMAND
+ */
+
+void PasswordSafeFrame::OnCopyRunCmd(wxCommandEvent& evt)
+{
+  CItemData rueItem;
+  CItemData* item = IsRUEEvent(evt)? (m_RUEList.GetPWEntry(GetEventRUEIndex(evt), rueItem)? &rueItem: NULL) : GetSelectedEntry();
+  if (item != NULL)
+    DoCopyRunCmd(*item);
+}
+
+void PasswordSafeFrame::DoCopyRunCmd(CItemData &item)
+{
+  PWSclip::SetData(item.GetRunCommand());
+  UpdateAccessTime(item);
+}
+
 
 
 /*!
@@ -332,7 +362,7 @@ void PasswordSafeFrame::OnCopyEmailClick(wxCommandEvent& evt)
  * wxEVT_COMMAND_MENU_SELECTED event handler for ID_CREATESHORTCUT
  */
 
-void PasswordSafeFrame::OnCreateShortcut(wxCommandEvent& /*evt*/)
+void PasswordSafeFrame::OnCreateShortcut(wxCommandEvent& WXUNUSED(event))
 {
   CItemData* item = GetSelectedEntry();
   if (item && !item->IsDependent()) {
@@ -347,7 +377,7 @@ void PasswordSafeFrame::OnCreateShortcut(wxCommandEvent& /*evt*/)
 }
 
 // Duplicate selected entry but make title unique
-void PasswordSafeFrame::OnDuplicateEntry(wxCommandEvent& /*evt*/)
+void PasswordSafeFrame::OnDuplicateEntry(wxCommandEvent& WXUNUSED(event))
 {
   if (m_core.IsReadOnly()) // disable in read-only mode
     return;
@@ -396,10 +426,10 @@ void PasswordSafeFrame::OnDuplicateEntry(wxCommandEvent& /*evt*/)
       if (pbci != NULL) {
         CUUID base_uuid = pbci->GetUUID();
         StringX cs_tmp;
-        cs_tmp = L"[" +
-          pbci->GetGroup() + L":" +
-          pbci->GetTitle() + L":" +
-          pbci->GetUser()  + L"]";
+        cs_tmp = wxT("[") +
+          pbci->GetGroup() + wxT(":") +
+          pbci->GetTitle() + wxT(":") +
+          pbci->GetUser()  + wxT("]");
         ci2.SetPassword(cs_tmp);
         pcmd = AddEntryCommand::Create(&m_core, ci2, base_uuid);
       }
@@ -415,7 +445,7 @@ void PasswordSafeFrame::OnDuplicateEntry(wxCommandEvent& /*evt*/)
     CUUID uuid = ci2.GetUUID();
     ItemListIter iter = m_core.Find(uuid);
     ASSERT(iter != m_core.GetEntryEndIter());
-
+    wxUnusedVar(iter); // used in assert only
 //    InsertItemIntoGUITreeList(m_core.GetEntry(iter));
 //    FixListIndexes();
     SetChanged(Data);
@@ -437,10 +467,10 @@ void PasswordSafeFrame::DoCopyURL(CItemData &item)
 
 void PasswordSafeFrame::DoCopyEmail(CItemData &item)
 {
-  const StringX mailto = item.IsEmailEmpty()? 
-                      (item.IsURLEmail()? item.GetURL(): StringX()) 
+  const StringX mailto = item.IsEmailEmpty()?
+                      (item.IsURLEmail()? item.GetURL(): StringX())
                       : item.GetEmail();
-  
+
   if (!mailto.empty()) {
     PWSclip::SetData(mailto);
     UpdateAccessTime(item);
@@ -476,9 +506,7 @@ void PasswordSafeFrame::DoAutotype(CItemData &ci)
   if (bMinOnAuto) {
     // Need to save display status for when we return from minimize
     //m_vGroupDisplayState = GetGroupDisplayState();
-    Iconize(true);
-    while (!IsIconized())
-      wxSafeYield();
+    TryIconize();
   } else {
     m_guiInfo->Save(this);
     Hide();
@@ -519,21 +547,21 @@ void PasswordSafeFrame::DoAutotype(CItemData &ci)
 /*
  * The entire logic is borrowed from ui/Windows/MainEdit.cpp
  */
-void PasswordSafeFrame::DoAutotype(const StringX& sx_autotype, 
-					const std::vector<size_t>& vactionverboffsets)
+void PasswordSafeFrame::DoAutotype(const StringX& sx_autotype,
+          const std::vector<size_t>& vactionverboffsets)
 {
   // All parsing of AutoType command done in one place: PWSAuxParse::GetAutoTypeString
   // Except for anything involving time (\d, \w, \W) or use older method (\z)
-  StringX sxtmp(L"");
+  StringX sxtmp(wxT(""));
   StringX sxautotype(sx_autotype);
   wchar_t curChar;
- 
+
   const int N = static_cast<int>(sxautotype.length());
 
   CKeySend ks;
 #ifdef __WXMAC__
   if (!ks.SimulateApplicationSwitch()) {
-    wxMessageBox(wxT("Error switching to another application before autotyping. Switch manually within 5 seconds"), 
+    wxMessageBox(_("Error switching to another application before autotyping. Switch manually within 5 seconds"),
                   wxTheApp->GetAppName(), wxOK|wxICON_ERROR, this);
     pws_os::sleep_ms(5000);
   }
@@ -543,7 +571,7 @@ void PasswordSafeFrame::DoAutotype(const StringX& sx_autotype,
 #endif
   //sleep for 1 second
   pws_os::sleep_ms(1000); // Karl Student's suggestion, to ensure focus set correctly on minimize.
-    
+
   int gNumIts;
   for (int n = 0; n < N; n++){
     curChar = sxautotype[n];
@@ -558,7 +586,7 @@ void PasswordSafeFrame::DoAutotype(const StringX& sx_autotype,
         case L'd':
         case L'w':
         case L'W':
-        { 
+        {
            if (std::find(vactionverboffsets.begin(), vactionverboffsets.end(), n - 1) ==
                vactionverboffsets.end()) {
              // Not in the list of found action verbs - treat as-is
@@ -583,7 +611,7 @@ void PasswordSafeFrame::DoAutotype(const StringX& sx_autotype,
           // Delay is going to change - send what we have with old delay
           ks.SendString(sxtmp);
           // start collecting new delay
-          sxtmp = L"";
+          sxtmp = wxT("");
           int newdelay = 0;
           gNumIts = 0;
           for (n++; n < N && (gNumIts < 3); ++gNumIts, n++) {
@@ -600,7 +628,7 @@ void PasswordSafeFrame::DoAutotype(const StringX& sx_autotype,
             ks.SetAndDelay(newdelay);
           }
           else
-            pws_os::sleep_ms(newdelay * (curChar == L'w' ? 1 : 1000)); 
+            pws_os::sleep_ms(newdelay * (curChar == L'w' ? 1 : 1000));
 
           break; // case 'd', 'w' & 'W'
         }
@@ -632,14 +660,14 @@ void PasswordSafeFrame::DoAutotype(const StringX& sx_autotype,
   }
   ks.SendString(sxtmp);
 
-  pws_os::sleep_ms(1000); 
+  pws_os::sleep_ms(1000);
 
 }
 
 void PasswordSafeFrame::DoBrowse(CItemData &item, bool bAutotype)
 {
   CItemData* pci = &item;
-  
+
   StringX sx_pswd;
   if (pci->IsDependent()) {
     CItemData *pbci = m_core.GetBaseEntry(pci);
@@ -649,15 +677,15 @@ void PasswordSafeFrame::DoBrowse(CItemData &item, bool bAutotype)
       pci = pbci;
   } else
     sx_pswd = pci->GetPassword();
-  
+
   wxString cs_command = towxstring(pci->GetURL());
-  
+
   if (!cs_command.IsEmpty()) {
     std::vector<size_t> vactionverboffsets;
     StringX sxautotype = PWSAuxParse::GetAutoTypeString(*pci, m_core,
                                                         vactionverboffsets);
     LaunchBrowser(cs_command, sxautotype, vactionverboffsets, bAutotype);
-#ifdef NOT_YET    
+#ifdef NOT_YET
     SetClipboardData(sx_pswd);
     UpdateLastClipboardAction(CItemData::PASSWORD);
 #endif
@@ -675,10 +703,10 @@ BOOL PasswordSafeFrame::LaunchBrowser(const wxString &csURL, const StringX &/*sx
    */
   wxString theURL(csURL);
   theURL.Replace(wxT("\n\t\r"), wxT(""), true); //true => replace all
-  
+
   const bool isMailto = (theURL.Find(wxT("mailto:")) != wxNOT_FOUND);
   const wxString errMsg = isMailto ? _("Unable to send email") : _("Unable to display URL");
-  
+
   const size_t altReplacements = theURL.Replace(wxT("[alt]"), wxT(""));
   const size_t alt2Replacements = (theURL.Replace(wxT("[ssh]"), wxT("")) +
                           theURL.Replace(wxT("{alt}"), wxT("")));
@@ -689,34 +717,34 @@ BOOL PasswordSafeFrame::LaunchBrowser(const wxString &csURL, const StringX &/*sx
 
   if (alt2Replacements == 0 && !isMailto && theURL.Find(wxT("://")) == wxNOT_FOUND)
     theURL = wxT("http://") + theURL;
-  
+
   const wxString sxAltBrowser(towxstring(PWSprefs::GetInstance()->GetPref(PWSprefs::AltBrowser)));
   const bool useAltBrowser = ((altReplacements > 0 || alt2Replacements > 0) && !sxAltBrowser.empty());
-  
+
   wxString sxFile, sxParameters;
   if (!useAltBrowser) {
     sxFile = theURL;
-  } 
+  }
   else { // alternate browser specified, invoke w/optional args
     sxFile = sxAltBrowser;
     wxString sxCmdLineParms(towxstring(PWSprefs::GetInstance()->
                            GetPref(PWSprefs::AltBrowserCmdLineParms)));
-    
+
     if (!sxCmdLineParms.empty())
       sxParameters = sxCmdLineParms + wxT(" ") + theURL;
     else
       sxParameters = theURL;
   }
-  
+
   sxFile.Trim(false); //false => from left
-  
+
 #ifdef NOT_YET
   // Obey user's No Autotype flag [xa]
   if (no_autotype > 0) {
     m_bDoAutoType = false;
     m_AutoType.clear();
     m_vactionverboffsets.clear();
-  } 
+  }
   else {
     // Either do it because they pressed the right menu/shortcut
     // or they had specified Do Auotype flag [autotype]
@@ -727,7 +755,7 @@ BOOL PasswordSafeFrame::LaunchBrowser(const wxString &csURL, const StringX &/*sx
   }
 #endif
 
-#ifdef NOT_YET 
+#ifdef NOT_YET
   bool rc = m_runner.issuecmd(sxFile, sxParameters, !m_AutoType.empty());
 #else
   bool rc;
@@ -739,7 +767,7 @@ BOOL PasswordSafeFrame::LaunchBrowser(const wxString &csURL, const StringX &/*sx
     rc= ::wxLaunchDefaultBrowser(sxFile);
   }
 #endif
-  
+
   if (!rc) {
     wxMessageBox(errMsg, wxTheApp->GetAppName(), wxOK|wxICON_STOP, this);
   }
@@ -748,13 +776,16 @@ BOOL PasswordSafeFrame::LaunchBrowser(const wxString &csURL, const StringX &/*sx
 
 void PasswordSafeFrame::DoRun(CItemData& item)
 {
-  UpdateAccessTime(item);
+  const StringX runee = item.GetRunCommand();
+  PWSRun runner;
+  if (runner.runcmd(runee, false))
+    UpdateAccessTime(item);
 }
 
 void PasswordSafeFrame::DoEmail(CItemData& item )
 {
-  const wxString mailto = item.IsEmailEmpty()? 
-                      (item.IsURLEmail()? towxstring(item.GetURL()): wxString()) 
+  const wxString mailto = item.IsEmailEmpty()?
+                      (item.IsURLEmail()? towxstring(item.GetURL()): wxString())
                       : towxstring(item.GetEmail());
   if (!mailto.empty()) {
     ::wxLaunchDefaultBrowser(mailto, wxBROWSER_NEW_WINDOW);
