@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-2014 Rony Shapiro <ronys@users.sourceforge.net>.
+ * Copyright (c) 2003-2015 Rony Shapiro <ronys@users.sourceforge.net>.
  * All rights reserved. Use of the code is allowed under the
  * Artistic License 2.0 terms, as specified in the LICENSE file
  * distributed with this code, or available from
@@ -108,7 +108,7 @@ bool CSafeCombinationChange::Create( wxWindow* parent, wxWindowID id, const wxSt
   m_yubiMixin2.SetupMixin(FindWindow(ID_YUBIBTN2), FindWindow(ID_YUBISTATUS));
   m_yubiMixin2.SetPrompt1(_("Enter old safe combination (if any) and click on top Yubikey button"));
   m_pollingTimer = new wxTimer(this, CYubiMixin::POLLING_TIMER_ID);
-  m_pollingTimer->Start(250); // check for Yubikey every 250ms.
+  m_pollingTimer->Start(500); // check for Yubikey every 500ms (250 is too often when we have 2 yubiMixins)
 #endif
   return true;
 }
@@ -274,7 +274,8 @@ void CSafeCombinationChange::OnOkClick( wxCommandEvent& /* evt */ )
 {
   if (Validate() && TransferDataFromWindow()) {
     StringX errmess;
-    int rc = m_core.CheckPasskey(m_core.GetCurFile(), m_oldpasswd);
+    const StringX old = m_oldresponse.empty() ? m_oldpasswd : m_oldresponse;
+    int rc = m_core.CheckPasskey(m_core.GetCurFile(), old);
     if (rc == PWScore::WRONG_PASSWORD) {
       wxMessageDialog err(this, _("The old safe combination is not correct"),
                           _("Error"), wxOK | wxICON_EXCLAMATION);
@@ -337,7 +338,7 @@ void CSafeCombinationChange::OnCancelClick( wxCommandEvent& /* evt */ )
 
 void CSafeCombinationChange::OnYubibtnClick( wxCommandEvent& /* event */ )
 {
-  // Here we just need to get the existing c/r. We verify it as a curtesy to the user,
+  // Here we just need to get the existing c/r. We verify it as a courtesy to the user,
   // that is, to indicate asap that it's incorrect.
   m_oldresponse.clear();
   // Allow blank password when Yubi's used
@@ -347,7 +348,8 @@ void CSafeCombinationChange::OnYubibtnClick( wxCommandEvent& /* event */ )
 
   if (Validate() && TransferDataFromWindow()) {
     bool oldYubiChallenge = ::wxGetKeyState(WXK_SHIFT); // for pre-0.94 databases
-    if (m_yubiMixin1.PerformChallengeResponse(m_oldpasswd, m_oldresponse, oldYubiChallenge)) {
+    if (m_yubiMixin1.PerformChallengeResponse(this, m_oldpasswd,
+					      m_oldresponse, oldYubiChallenge)) {
       // Verify the response - a convenience, as we double check in OnYubibtn2Click().
       int rc = m_core.CheckPasskey(m_core.GetCurFile(), m_oldresponse);
       if (rc == PWScore::WRONG_PASSWORD) {
@@ -402,7 +404,7 @@ void CSafeCombinationChange::OnYubibtn2Click( wxCommandEvent& /* event */ )
     }
     StringX response;
     bool oldYubiChallenge = ::wxGetKeyState(WXK_SHIFT); // for pre-0.94 databases
-    if (m_yubiMixin2.PerformChallengeResponse(m_newpasswd, response, oldYubiChallenge)) {
+    if (m_yubiMixin2.PerformChallengeResponse(this, m_newpasswd, response, oldYubiChallenge)) {
       m_newpasswd = response;
       EndModal(wxID_OK);
     }
